@@ -2,10 +2,7 @@ test_that("issue", {
   # Avoid CRAN check errors due to unavailable network resources.
   skip_on_cran()
 
-  req <- HttpRequest(
-    method = "GET",
-    url = parse_url("https://httpbin.org/json")
-  )
+  req <- HttpRequest(method = "GET", url = parse_url("https://httpbin.org/json"))
   resp <- issue(req)
 
   # skip if network flaky
@@ -25,10 +22,8 @@ test_that("connect_timeout", {
     connect_timeout = 1
   )
   quietly <- function(expr)
-    suppressMessages(
-      tryCatch(expr, error = function(e) {
-      })
-    )
+    suppressMessages(tryCatch(expr, error = function(e) {
+    }))
   time <- system.time({
     quietly(issue(req))
   })
@@ -44,10 +39,8 @@ test_that("timeout", {
     timeout = 1
   )
   quietly <- function(expr)
-    suppressMessages(
-      tryCatch(expr, error = function(e) {
-      })
-    )
+    suppressMessages(tryCatch(expr, error = function(e) {
+    }))
   time <- system.time({
     quietly(issue(req))
   })
@@ -75,10 +68,7 @@ test_that("don't decompress the body when already decompressed", {
   # Avoid CRAN check errors due to unavailable network resources.
   skip_on_cran()
 
-  req <- HttpRequest(
-    method = "GET",
-    url = parse_url("https://httpbin.org/gzip")
-  )
+  req <- HttpRequest(method = "GET", url = parse_url("https://httpbin.org/gzip"))
 
   expect_error(resp <- issue(req), NA)
 
@@ -113,14 +103,9 @@ test_that("write content to disk", {
 })
 
 test_that("check issue", {
-  req <- HttpRequest(
-    method = "GET",
-    url = parse_url("https://httpbin.org/json")
-  )
+  req <- HttpRequest(method = "GET", url = parse_url("https://httpbin.org/json"))
 
-  mock_request_aws <- mock2(
-    httr2::response(body = charToRaw("dummy"))
-  )
+  mock_request_aws <- mock2(httr2::response(body = charToRaw("dummy")))
   mockery::stub(issue, "request_aws", mock_request_aws)
 
   resp <- issue(req)
@@ -130,10 +115,7 @@ test_that("check issue", {
 
 test_that("check request_aws", {
   url <- "https://httpbin.org/json"
-  req <- HttpRequest(
-    method = "GET",
-    url = parse_url(url)
-  )
+  req <- HttpRequest(method = "GET", url = parse_url(url))
   mock_req_perform <- mock2()
   mock_req_perform_conn <- mock2()
 
